/**
 * @packageDocumentation
 * @module Hooks
 * @internal
 */
import React from 'react';
import { useTranslation } from 'react-i18next';
import * as DateTimeFormatter from '../lib/date-time-formatter';
export const useLanguageLocale = () => {
  const {
    t,
    i18n
  } = useTranslation();
  const tFunctionWithNoDataDefault = React.useCallback((key, options) => {
    if (typeof options === 'object' && options.count === undefined) {
      // eslint-disable-next-line @typescript-eslint/restrict-template-expressions
      return t(`${key}_noData`, {
        defaultValue: t(key, options),
        ...options
      });
    }

    return t(key, options);
  }, [t]);
  return React.useMemo(() => ({
    t: tFunctionWithNoDataDefault,
    formatDateTime: dateTime => DateTimeFormatter.formatDateTime(dateTime, i18n.language),
    formatMonthLong: dateTime => DateTimeFormatter.formatMonthLong(dateTime, i18n.language),
    formatDate: dateTime => DateTimeFormatter.formatDate(dateTime, i18n.language),
    formatDateShort: dateTime => DateTimeFormatter.formatDateShort(dateTime, i18n.language),
    formatTime: dateTime => DateTimeFormatter.formatTime(dateTime, i18n.language),
    formatTimeShort: dateTime => DateTimeFormatter.formatTimeShort(dateTime, i18n.language),
    timeSince: dateTime => DateTimeFormatter.timeSince(dateTime)
  }), [tFunctionWithNoDataDefault, i18n]);
};
//# sourceMappingURL=language-locale-hooks.js.map